=== modified file 'bzrlib/check.py'
--- bzrlib/check.py	2006-03-07 12:56:15 +0000
+++ bzrlib/check.py	2006-03-20 22:32:41 +0000
@@ -1,5 +1,4 @@
-# Copyright (C) 2004, 2005 by Martin Pool
-# Copyright (C) 2005 by Canonical Ltd
+# Copyright (C) 2005, 2006 by Canonical Ltd
 
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -28,6 +27,11 @@
 # TODO: Get every revision in the revision-store even if they're not
 # referenced by history and make sure they're all valid.
 
+# TODO: Perhaps have a way to record errors other than by raising exceptions;
+# would perhaps be enough to accumulate exception objects in a list without
+# raising them.  If there's more than one exception it'd be good to see them
+# all.
+
 import bzrlib.ui
 from bzrlib.trace import note, warning
 from bzrlib.osutils import rename, sha_string, fingerprint_file
@@ -39,6 +43,8 @@
 class Check(object):
     """Check a branch"""
 
+    # The Check object interacts with InventoryEntry.check, etc.
+
     def __init__(self, branch):
         self.branch = branch
         self.repository = branch.repository
@@ -49,7 +55,7 @@
         self.missing_parent_links = {}
         self.missing_inventory_sha_cnt = 0
         self.missing_revision_cnt = 0
-        # maps (file-id, version) -> sha1
+        # maps (file-id, version) -> sha1; used by InventoryFile._check
         self.checked_texts = {}
         self.checked_weaves = {}
 

=== modified file 'bzrlib/inventory.py'
--- bzrlib/inventory.py	2006-03-11 08:50:10 +0000
+++ bzrlib/inventory.py	2006-03-20 22:32:41 +0000
@@ -328,6 +328,14 @@
 
         This is a template method, override _check for kind specific
         tests.
+
+        :param checker: Check object providing context for the checks; 
+             can be used to find out what parts of the repository have already
+             been checked.
+        :param rev_id: Revision id from which this InventoryEntry was loaded.
+             Not necessarily the last-changed revision for this file.
+        :param inv: Inventory from which the entry was loaded.
+        :param tree: RevisionTree for this entry.
         """
         if self.parent_id != None:
             if not inv.has_id(self.parent_id):
@@ -511,15 +519,14 @@
 class InventoryFile(InventoryEntry):
     """A file in an inventory."""
 
-    def _check(self, checker, rev_id, tree):
+    def _check(self, checker, tree_revision_id, tree):
         """See InventoryEntry._check"""
-        revision = self.revision
-        t = (self.file_id, revision)
+        t = (self.file_id, self.revision)
         if t in checker.checked_texts:
-            prev_sha = checker.checked_texts[t] 
+            prev_sha = checker.checked_texts[t]
             if prev_sha != self.text_sha1:
                 raise BzrCheckError('mismatched sha1 on {%s} in {%s}' %
-                                    (self.file_id, rev_id))
+                                    (self.file_id, tree_revision_id))
             else:
                 checker.repeated_text_cnt += 1
                 return
@@ -535,7 +542,7 @@
         else:
             w = tree.get_weave(self.file_id)
 
-        mutter('check version {%s} of {%s}', rev_id, self.file_id)
+        mutter('check version {%s} of {%s}', tree_revision_id, self.file_id)
         checker.checked_text_cnt += 1 
         # We can't check the length, because Weave doesn't store that
         # information, and the whole point of looking at the weave's

=== modified file 'bzrlib/weave.py'
--- bzrlib/weave.py	2006-03-14 10:27:28 +0000
+++ bzrlib/weave.py	2006-03-20 22:32:41 +0000
@@ -863,7 +863,8 @@
 
     def check(self, progress_bar=None):
         # TODO evaluate performance hit of using string sets in this routine.
-        # check no circular inclusions
+        # TODO: check no circular inclusions
+        # TODO: create a nested progress bar
         for version in range(self.num_versions()):
             inclusions = list(self._parents[version])
             if inclusions:

